jnf
产品支持情况
- Ascend 950PR/Ascend 950DT:支持
- Atlas A3 训练系列产品/Atlas A3 推理系列产品:不支持
- Atlas A2 训练系列产品/Atlas A2 推理系列产品:不支持
- Atlas 200I/500 A2 推理产品:不支持
- Atlas 推理系列产品AI Core:不支持
- Atlas 推理系列产品Vector Core:不支持
- Atlas 训练系列产品:不支持
功能说明
获取输入数据x的n阶第一类贝塞尔函数jn的值。

函数原型
C++
inline float jnf(int n, float x)
参数说明
表1 参数说明
| 参数名 | 输入/输出 | 描述 |
|---|---|---|
| n | 输入 | 源操作数。 |
| x | 输入 | 源操作数。 |
返回值说明
输入数据的n阶第一类贝塞尔函数jn的值。
- 当n<0时,返回值为nan。
- 当x=inf或-inf时,返回值为0。
- 当x=nan时,返回值为nan。
约束说明
- n的最大取值为128。
- 针对Ascend 950PR/Ascend 950DT,本接口不支持Subnormal场景:本接口内部实现使用到了expf,由于expf不支持Subnormal场景,在极少数场景下内部计算的expf结果为Subnormal数据,导致本接口最终结果为0。
需要包含的头文件
使用该接口需要包含"simt_api/math_functions.h"头文件。
C++
#include "simt_api/math_functions.h"
调用示例
SIMT编程场景:
C++__global__ __launch_bounds__(256) void compute_jnf(float *result, const int *n, const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = jnf(n[idx], x[idx]); }SIMD与SIMT混合编程场景:
C++__simt_vf__ __launch_bounds__(256) inline void compute_jnf_vf(__gm__ float *result, __gm__ const int *n, __gm__ const float *x, uint32_t count) { const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x; if (idx >= count) { return; } result[idx] = jnf(n[idx], x[idx]); } __global__ __vector__ void run_jnf(__gm__ float *result, __gm__ const int *n, __gm__ const float *x, uint32_t count) { asc_vf_call<compute_jnf_vf>(dim3(256), result, n, x, count); }
输入输出示例如下:
Text
n:1, 2, 3, 1
x:0.25, 0.75, 1.25, 1.75
result: 0.124026 0.06707399 0.03686836 0.5801562